@@ -38,6 +38,13 @@ function(..., deparse.level = 1)
     if (any(t <- unlist(lapply(dots, is.null))))
         dots[t] <- NULL
 
+    # deal with numeric values
+    vecIdx <- sapply(dots, function(obj)
+                     (!inherits(obj, "timeSeries") && prod(dim(obj)) == 1))
+    if (any(vecIdx))
+        dots[vecIdx] <- lapply(dots[vecIdx], function(vec)
+                               as.timeSeries(rep(as.vector(vec), len = NROW(dots[[1]]))))
+
     # coerce to timeSeries object if not a timeSeries
     if (any(t <- !unlist(lapply(dots, inherits, "timeSeries"))))
         dots[t] <- lapply(dots[t], as.timeSeries)
@@ -59,12 +66,6 @@ function(..., deparse.level = 1)
     # ensure that data is sorted
     dots <- lapply(dots, sort)
 
-    # deal with single numeric values
-    vecIdx <- sapply(dots, function(obj) (prod(dim(obj)) == 1))
-    if (any(vecIdx))
-        dots[vecIdx] <- lapply(dots[vecIdx], function(vec)
-                               as.timeSeries(rep(as.vector(vec), nrow(dots[[1]]))))
-
     # get list of timestamps and recordIDs
     tds <- lapply(dots, slot, "positions")
     rec <- lapply(dots, slot, "recordIDs")
@@ -76,10 +77,10 @@ function(..., deparse.level = 1)
     {
 
         # check if all have same number of rows
-        if (diff(range((unlist(lapply(dots, nrow))))))
+        if (diff(range((unlist(lapply(dots, NROW))))))
             stop("number of rows must match")
         td <- if (any(!co)) tds[!co][[1]] else NULL
-        data <- array(unlist(dots), dim=c(nrow(dots[[1]]),
+        data <- array(unlist(dots), dim=c(NROW(dots[[1]]),
                                     sum(sapply(dots, ncol))))
         recordIDs <-
             if (sum(recIdx <- sapply(rec, length)))
